@@ -45,7 +45,7 @@ AkonadiIndexingAgent::AkonadiIndexingAgent(const QString &id)
 
     Akonadi::AttributeFactory::registerAttribute<Akonadi::IndexPolicyAttribute>();
 
-    KConfigGroup cfg = config()->group("General");
+    KConfigGroup cfg = config()->group(QStringLiteral("General"));
     const int agentIndexingVersion = cfg.readEntry("agentIndexingVersion", 0);
     bool respectDiacriticAndAccents = cfg.readEntry("respectDiacriticAndAccents", true);
     if (agentIndexingVersion < INDEXING_AGENT_VERSION) {
@@ -87,7 +87,7 @@ AkonadiIndexingAgent::AkonadiIndexingAgent(const QString &id)
 
     new IndexerAdaptor(this);
 
-    // Cleanup agentsrc after migration to 4.13/KF5
+    // Cleanup agentsrc after migration to 4.13/KF6
     Akonadi::AgentManager *agentManager = Akonadi::AgentManager::self();
     const Akonadi::AgentInstance::List allAgents = agentManager->instances();
     // Cannot use agentManager->instance(oldInstanceName) here, it wouldn't find broken instances.
@@ -295,7 +295,7 @@ int AkonadiIndexingAgent::numberOfCollectionQueued()
 
 void AkonadiIndexingAgent::onAbortRequested()
 {
-    KConfigGroup group = config()->group("General");
+    KConfigGroup group = config()->group(QStringLiteral("General"));
     group.writeEntry("aborted", true);
     group.sync();
     m_scheduler.abort();
@@ -309,7 +309,7 @@ void AkonadiIndexingAgent::onOnlineChanged(bool online)
     // Index items that might have changed while we were offline
     if (online) {
         // We only reindex if this is not a regular start
-        KConfigGroup cfg = config()->group("General");
+        KConfigGroup cfg = config()->group(QStringLiteral("General"));
         bool aborted = cfg.readEntry("aborted", false);
         if (aborted) {
             cfg.writeEntry("aborted", false);
@@ -333,3 +333,5 @@ bool AkonadiIndexingAgent::shouldIndex(const Akonadi::Item &item) const
 }
 
 AKONADI_AGENT_MAIN(AkonadiIndexingAgent)
+
+#include "moc_agent.cpp"
