@@ -65,14 +65,14 @@ void AkonadiSearchDebugDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(800, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myAkonadiSearchDebugDialogConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myAkonadiSearchDebugDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void AkonadiSearchDebugDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myAkonadiSearchDebugDialogConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myAkonadiSearchDebugDialogConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
@@ -110,7 +110,7 @@ void AkonadiSearchDebugDialog::saveTextAs(const QString &text, const QString &fi
                                     "\"%2\" is the detailed error description.",
                                     fileName,
                                     QString::fromLocal8Bit(strerror(errno))),
-                               i18n("Save File Error"));
+                               i18nc("@title:window", "Save File Error"));
         }
     }
     delete fdlg;
@@ -123,10 +123,9 @@ bool AkonadiSearchDebugDialog::saveToFile(const QString &filename, const QString
         return false;
     }
     QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    out.setCodec("UTF-8");
-#endif
     out << text;
     file.close();
     return true;
 }
+
+#include "moc_akonadisearchdebugdialog.cpp"
